@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.tpu_v1.services.tpu import pagers
@@ -164,17 +166,17 @@ class TpuAsyncClient:
 
     async def list_nodes(
         self,
-        request: cloud_tpu.ListNodesRequest = None,
+        request: Union[cloud_tpu.ListNodesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListNodesAsyncPager:
         r"""Lists nodes.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.ListNodesRequest`):
+            request (Union[google.cloud.tpu_v1.types.ListNodesRequest, dict]):
                 The request object. Request for
                 [ListNodes][google.cloud.tpu.v1.Tpu.ListNodes].
             parent (:class:`str`):
@@ -242,17 +244,17 @@ class TpuAsyncClient:
 
     async def get_node(
         self,
-        request: cloud_tpu.GetNodeRequest = None,
+        request: Union[cloud_tpu.GetNodeRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloud_tpu.Node:
         r"""Gets the details of a node.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.GetNodeRequest`):
+            request (Union[google.cloud.tpu_v1.types.GetNodeRequest, dict]):
                 The request object. Request for
                 [GetNode][google.cloud.tpu.v1.Tpu.GetNode].
             name (:class:`str`):
@@ -309,19 +311,19 @@ class TpuAsyncClient:
 
     async def create_node(
         self,
-        request: cloud_tpu.CreateNodeRequest = None,
+        request: Union[cloud_tpu.CreateNodeRequest, dict] = None,
         *,
         parent: str = None,
         node: cloud_tpu.Node = None,
         node_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a node.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.CreateNodeRequest`):
+            request (Union[google.cloud.tpu_v1.types.CreateNodeRequest, dict]):
                 The request object. Request for
                 [CreateNode][google.cloud.tpu.v1.Tpu.CreateNode].
             parent (:class:`str`):
@@ -404,17 +406,17 @@ class TpuAsyncClient:
 
     async def delete_node(
         self,
-        request: cloud_tpu.DeleteNodeRequest = None,
+        request: Union[cloud_tpu.DeleteNodeRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a node.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.DeleteNodeRequest`):
+            request (Union[google.cloud.tpu_v1.types.DeleteNodeRequest, dict]):
                 The request object. Request for
                 [DeleteNode][google.cloud.tpu.v1.Tpu.DeleteNode].
             name (:class:`str`):
@@ -483,16 +485,16 @@ class TpuAsyncClient:
 
     async def reimage_node(
         self,
-        request: cloud_tpu.ReimageNodeRequest = None,
+        request: Union[cloud_tpu.ReimageNodeRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Reimages a node's OS.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.ReimageNodeRequest`):
+            request (Union[google.cloud.tpu_v1.types.ReimageNodeRequest, dict]):
                 The request object. Request for
                 [ReimageNode][google.cloud.tpu.v1.Tpu.ReimageNode].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -542,16 +544,16 @@ class TpuAsyncClient:
 
     async def stop_node(
         self,
-        request: cloud_tpu.StopNodeRequest = None,
+        request: Union[cloud_tpu.StopNodeRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Stops a node.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.StopNodeRequest`):
+            request (Union[google.cloud.tpu_v1.types.StopNodeRequest, dict]):
                 The request object. Request for
                 [StopNode][google.cloud.tpu.v1.Tpu.StopNode].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -601,16 +603,16 @@ class TpuAsyncClient:
 
     async def start_node(
         self,
-        request: cloud_tpu.StartNodeRequest = None,
+        request: Union[cloud_tpu.StartNodeRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Starts a node.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.StartNodeRequest`):
+            request (Union[google.cloud.tpu_v1.types.StartNodeRequest, dict]):
                 The request object. Request for
                 [StartNode][google.cloud.tpu.v1.Tpu.StartNode].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -660,17 +662,17 @@ class TpuAsyncClient:
 
     async def list_tensor_flow_versions(
         self,
-        request: cloud_tpu.ListTensorFlowVersionsRequest = None,
+        request: Union[cloud_tpu.ListTensorFlowVersionsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTensorFlowVersionsAsyncPager:
         r"""List TensorFlow versions supported by this API.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.ListTensorFlowVersionsRequest`):
+            request (Union[google.cloud.tpu_v1.types.ListTensorFlowVersionsRequest, dict]):
                 The request object. Request for
                 [ListTensorFlowVersions][google.cloud.tpu.v1.Tpu.ListTensorFlowVersions].
             parent (:class:`str`):
@@ -738,17 +740,17 @@ class TpuAsyncClient:
 
     async def get_tensor_flow_version(
         self,
-        request: cloud_tpu.GetTensorFlowVersionRequest = None,
+        request: Union[cloud_tpu.GetTensorFlowVersionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloud_tpu.TensorFlowVersion:
         r"""Gets TensorFlow Version.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.GetTensorFlowVersionRequest`):
+            request (Union[google.cloud.tpu_v1.types.GetTensorFlowVersionRequest, dict]):
                 The request object. Request for
                 [GetTensorFlowVersion][google.cloud.tpu.v1.Tpu.GetTensorFlowVersion].
             name (:class:`str`):
@@ -807,17 +809,17 @@ class TpuAsyncClient:
 
     async def list_accelerator_types(
         self,
-        request: cloud_tpu.ListAcceleratorTypesRequest = None,
+        request: Union[cloud_tpu.ListAcceleratorTypesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAcceleratorTypesAsyncPager:
         r"""Lists accelerator types supported by this API.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.ListAcceleratorTypesRequest`):
+            request (Union[google.cloud.tpu_v1.types.ListAcceleratorTypesRequest, dict]):
                 The request object. Request for
                 [ListAcceleratorTypes][google.cloud.tpu.v1.Tpu.ListAcceleratorTypes].
             parent (:class:`str`):
@@ -885,17 +887,17 @@ class TpuAsyncClient:
 
     async def get_accelerator_type(
         self,
-        request: cloud_tpu.GetAcceleratorTypeRequest = None,
+        request: Union[cloud_tpu.GetAcceleratorTypeRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloud_tpu.AcceleratorType:
         r"""Gets AcceleratorType.
 
         Args:
-            request (:class:`google.cloud.tpu_v1.types.GetAcceleratorTypeRequest`):
+            request (Union[google.cloud.tpu_v1.types.GetAcceleratorTypeRequest, dict]):
                 The request object. Request for
                 [GetAcceleratorType][google.cloud.tpu.v1.Tpu.GetAcceleratorType].
             name (:class:`str`):
