@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.tpu_v1.services.tpu import pagers
@@ -391,7 +393,7 @@ class TpuClient(metaclass=TpuClientMeta):
         request: Union[cloud_tpu.ListNodesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListNodesPager:
@@ -469,7 +471,7 @@ class TpuClient(metaclass=TpuClientMeta):
         request: Union[cloud_tpu.GetNodeRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloud_tpu.Node:
@@ -538,7 +540,7 @@ class TpuClient(metaclass=TpuClientMeta):
         parent: str = None,
         node: cloud_tpu.Node = None,
         node_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -631,7 +633,7 @@ class TpuClient(metaclass=TpuClientMeta):
         request: Union[cloud_tpu.DeleteNodeRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -709,7 +711,7 @@ class TpuClient(metaclass=TpuClientMeta):
         self,
         request: Union[cloud_tpu.ReimageNodeRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -769,7 +771,7 @@ class TpuClient(metaclass=TpuClientMeta):
         self,
         request: Union[cloud_tpu.StopNodeRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -829,7 +831,7 @@ class TpuClient(metaclass=TpuClientMeta):
         self,
         request: Union[cloud_tpu.StartNodeRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -890,7 +892,7 @@ class TpuClient(metaclass=TpuClientMeta):
         request: Union[cloud_tpu.ListTensorFlowVersionsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTensorFlowVersionsPager:
@@ -970,7 +972,7 @@ class TpuClient(metaclass=TpuClientMeta):
         request: Union[cloud_tpu.GetTensorFlowVersionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloud_tpu.TensorFlowVersion:
@@ -1039,7 +1041,7 @@ class TpuClient(metaclass=TpuClientMeta):
         request: Union[cloud_tpu.ListAcceleratorTypesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAcceleratorTypesPager:
@@ -1117,7 +1119,7 @@ class TpuClient(metaclass=TpuClientMeta):
         request: Union[cloud_tpu.GetAcceleratorTypeRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloud_tpu.AcceleratorType:
